@@ -99,7 +99,7 @@ __copyright__ = """pyRad - a wheel type command menu.
 ### Constants ###
 
 #: The PyRad version identifier
-__version__ = "0.5.2"
+__version__ = "0.5.3"
 appName = "pyRad"
 
 ### Commandline handling ###
@@ -186,7 +186,7 @@ def createAboutData():
     license     = KAboutData.License_GPL
     copyright   = ki18n ("(c) 2009 Arne Babenhauserheide")
     text        = ki18n ("pyRad is heavily inspired by Kommando, which sadly didn't make it into KDE4. Kommando in turn was inspired by the Neverwinternights menu.")
-    homePage    = "http://draketo.de/light/english/pyrad"
+    homePage    = "draketo.de/light/english/pyrad"
     bugEmail    = "arne_bab@web.de"
 
     aboutData   = KAboutData (appName, catalog, programName, version, description,
