@@ -16,7 +16,7 @@ from math import sin, cos, pi
 # and parsing a command string into words for Popen
 from shlex import split as split_action
 # Finally some path tools for loading a config file
-from os.path import join, isfile
+from os.path import join, isfile, dirname
 
 # and system independent home folder location
 from user import home
@@ -92,7 +92,9 @@ Flattr me? :)""")
         loader = KIconLoader()
         flattr_pix = loader.loadIcon(join(sys.prefix, "share", "pyrad", "Wikimedia_Flattr_Button.png"), 0)
         if flattr_pix.isNull():
-            flattr_pix = loader.loadIcon(join("images", "Wikimedia_Flattr_Button.png"), 0)
+            flattr_pix = loader.loadIcon(join(dirname(__file__), "images", "Wikimedia_Flattr_Button.png"), 0)
+        if flattr_pix.isNull():
+            flattr_pix = loader.loadIcon(join(dirname(__file__), "share", "pyrad", "Wikimedia_Flattr_Button.png"), 0)
         ic = QIcon(flattr_pix) # for a QPushButten
         self.flattr_icon = QPushButton()
         self.flattr_icon.setIcon(ic)
